@@ -1,3 +1,22 @@
+/*
+ *  acm : an aerial combat simulator for X
+ *  Copyright (C) 1991-1998  Riley Rainey
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ */
+
 #include <Alib.h>
 #include <stdio.h>
 #include <memory.h>
@@ -6,7 +25,7 @@
 
 #include <X11/Xlib.h>
 
-extern char *malloc(size_t);
+/*extern char *malloc(size_t);*/
 
 #ifdef HAS_FRAME_BUFFER
 void
@@ -69,6 +88,9 @@ InitializeX11AWindow(Display * dpy, int screen, Drawable d, int flags)
 	w->csPool1 = (ColorSegment *) malloc(w->CSSize1 * sizeof(ColorSegment));
 	memset(w->csPool1, 0, w->CSSize1 * sizeof(ColorSegment));
 
+	w->CSSize2 = 0;
+	w->csPool2 = (ColorSegment *) NULL;
+
 	w->scanLine = (ScanLine *) malloc((w->height + 1) * sizeof(ScanLine));
 	w->lastScanLine = (ScanLine *) malloc((w->height + 1) * sizeof(ScanLine));
 	w->otherLastScanLine = NULL;
