@@ -1,3 +1,22 @@
+/*
+ *  acm : an aerial combat simulator for X
+ *  Copyright (C) 1991-1998  Riley Rainey
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ */
+
 #include "Vlib.h"
 
 #ifdef X11
@@ -140,7 +159,6 @@ VOpenViewport(Display * dpy, int screen, Window win, Colormap cmap, Visual * vis
 						 RootWindow(dpy, screen), width, height, planes);
 			v->flags |= VPPixmap;
 		}
-#ifdef HAVE_X11_DBE
 		if (v->flags & VPDoubleBuffer) {
 		  v->gc = XCreateGC(dpy, RootWindow(dpy, screen),
                                           0, NULL);
@@ -158,7 +176,6 @@ VOpenViewport(Display * dpy, int screen, Window win, Colormap cmap, Visual * vis
 
 		  return v;
 		}
-#endif
 
 		if (planes == 1 || _VDefaultWorkContext->usePixmaps != 0)
 			v->flags |= VPMono;
