@@ -1,3 +1,22 @@
+/*
+ *  acm : an aerial combat simulator for X
+ *  Copyright (C) 1991-1998  Riley Rainey
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ */
+
 #ifndef __Vlib
 #define __Vlib
 
@@ -7,7 +26,7 @@
 
 #define VmaxVP	2048			/* max # of vertices in a polygon */
 
-#define MAXCOLORS 8				/* max number of colors available */
+#define MAXCOLORS 16	   		/* max number of colors available */
 				/* when double buffering */
 
 #if (MAXCOLORS==4)
@@ -30,16 +49,12 @@
 #else /* ! WIN32 */
 
 #include <X11/Xlib.h>
-#ifdef HAVE_X11_DBE
 #include <X11/extensions/Xdbe.h>
 #endif
-#endif
 
 #include <Alib.h>
 #include <stdio.h>
-#if HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
 #if !defined(__GNUC__)
 #include <memory.h>
 #endif
@@ -130,10 +145,8 @@ typedef struct _Viewport {
 	int       screen;			/* X screen number */
 	Window    win;
 	Pixmap    monoPixmap;		/* Pixmap used to buffer drawing */
-#ifdef HAVE_X11_DBE
 	XdbeBackBuffer dbeDrawable;
 	GC        gc;
-#endif
 	Pixmap    halftone[8];		/* Pixmaps used for dithering images */
 
 	int       colors;			/* color count */
@@ -315,7 +328,7 @@ extern    "C" {
 	extern void AlibClose(Viewport *v);
 	extern Status AlibAllocColor(Viewport *v, Colormap colormap, XColor *c);
 
-
+#if 0
 #ifndef SYSV
 	extern char *strdup(const char *);
 #endif
@@ -325,7 +338,7 @@ extern    "C" {
 /* For some reason, the RS/6000 AIX header files don't declare strdup. */
 	extern char *strdup(const char *);
 #endif
-
+#endif
 #if defined(__cplusplus)
 };
 
