@@ -1,3 +1,22 @@
+/*
+ *  acm : an aerial combat simulator for X
+ *  Copyright (C) 1991-1998  Riley Rainey
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ */
+
 #if defined(mips) && !defined(ultrix) && !defined(sgi)
 
 #include </usr/include/sys/types.h>
@@ -148,8 +167,8 @@ static ColorLookup quickColors[] =
 	 {0, 0, 0, RGB(0, 0, 0), 0, 0}},
 	{"white",
 	 {0xffff, 0xffff, 0xffff, RGB(255, 255, 255), 0, 0}},
-	{"gray40",
-	 {xx(34 << 2), xx(34 << 2), xx(34 << 2), 0, 0, 0}},
+	{"lightgray",
+	 {xx(200), xx(200), xx(200), 0, 0, 0}},
 	{"gray44",
 	 {xx(28 << 2), xx(28 << 2), xx(28 << 2), 0, 0, 0}},
 	{"gray33",
