@@ -1,10 +1,11 @@
 /*
  *  acm : an aerial combat simulator for X
- *  Copyright (C) 1991,1992  Riley Rainey
+ *  Copyright (C) 1991-1998  Riley Rainey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,15 +13,17 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
+
 #include "../lib/Vlib.h"
 #include <X11/Xutil.h>
 #include <math.h>
 #include <sys/time.h>
+#include <unistd.h>
 
-#define VIEW1
+#define VIEW2
 
 extern Display  *dpy;
 extern Window   win;
@@ -59,6 +62,7 @@ void TimeIntervalAccounting() {
 	elapsedTotal += elapsedTime;
 	frameCount += 1;
 	lastTime = thisTime;
+    usleep(40000);
 }
 
 void PrintStatistics () {
