@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,16 +13,12 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 #include "alarm.h"
 #include <sys/param.h>
-#if defined(__STDC__) || defined(HAVE_STDLIB_H)
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
 
 static alarm_descriptor_t *alarm_list = NULL;
 static alarm_id_t next_alarm_id = 0;
