@@ -1,11 +1,11 @@
-
 /*
  *  acm : an aerial combat simulator for X
  *  Copyright (C) 1993 Riley Rainey, Tetsuji Rai
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,14 +13,14 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #include "pm.h"
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-#include <malloc.h>
+#include <stdlib.h>
 
 #define MAX_MAPPED_STRING_LEN	20
 #define MAX_POPUP_STRING_LEN	40
