@@ -1,11 +1,12 @@
 /*
+ *  acm : an aerial combat simulator for X
  *  Copyright (C) 1995  Mats Lofkvist  CelsiusTech Electronics AB
- *
  *  With additions by Riley Rainey, 1995-1998
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,11 +14,11 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
-static char rcsid[] = "$Id: dis_if.c,v 1.2 1998/05/12 03:59:37 riley Exp $";
+static char rcsid[] = "$Id: dis_if.c,v 1.1.1.1 2005/10/28 14:47:12 k0ro Exp $";
 
 #include <stdio.h>
 #include <math.h>
@@ -46,7 +47,8 @@ static int dis_initializeEMInfo ( Entity_t *e );
 #define DEFAULT_LOCATION_THRESHOLD      1.0
 #define DEFAULT_ORIENTATION_THRESHOLD   (3.0 * M_PI / 180.0)
 
-#define SEND_TIMEOUT_SECONDS	4.8
+/*#define SEND_TIMEOUT_SECONDS	4.8*/
+#define SEND_TIMEOUT_SECONDS    0.1
 #define RECV_TIMEOUT_SECONDS	12.0
 
 static dis_EntityEnterCb entityEnterCb = NULL;
@@ -708,6 +710,8 @@ entityStatePDU(dis_entity_state_pdu * esPDU)
 			return 0;
 		}
 		else {
+		  printf("unknown entity\n"); // SLP
+		  fflush(stdout);
 			eid = entityEnter(esPDU);
 			if (eid >= 0) {
 				return 0;
