@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #ifndef WIN32
@@ -50,7 +51,7 @@ extern long polyCount;
 
 void undersampleObject (VObject * obj, int rate);
 
-static char *errmsg = "Sorry, I cannot find the file %s in ../objects/, %s or %s\n";
+static char *errmsg = "Sorry, I cannot find the file %s in %s\n";
 
 extern void
   AddRunway (VMatrix * RWYtoXYZ, double length, double width, int flags,
@@ -60,7 +61,7 @@ extern void
  *  acm_fopen :  Open an important acm data file (or die trying).
  */
 
-char _acm_fopen_library_dir[2048];
+char _acm_fopen_library_dir[] = ACM_LIBRARY;
 
 FILE     *
 acm_fopen(char *name, char *access)
@@ -70,20 +71,11 @@ acm_fopen(char *name, char *access)
 	char      libname[256];
 
 	if ((f = fopen(name, access)) == (FILE *) NULL) {
-		strcpy(libname, "../objects/");
+		strcpy(libname, _acm_fopen_library_dir);
 		strcat(libname, name);
 		if ((f = fopen(libname, access)) == (FILE *) NULL) {
-			strcpy(libname, _acm_fopen_library_dir);
-			strcat(libname, name);
-			if ((f = fopen(libname, access)) == (FILE *) NULL) {
-				strcpy (libname, SRCDIR);
-				strcat (libname, "/../objects/");
-				strcat (libname, name);
-				if ((f = fopen(libname, access)) == (FILE *) NULL) {
-					fprintf(stderr, errmsg, name, _acm_fopen_library_dir, libname);
-					exit(1);
-				}
-			}
+            fprintf(stderr, errmsg, name, _acm_fopen_library_dir);
+            exit(1);
 		}
 	}
 
@@ -102,16 +94,12 @@ acm_find_file(char *name)
 
 	strcpy(pname, name);
 	if (stat(name, &statbuf) != 0) {
-		strcpy(pname, "../objects/");
+		strcpy(pname, _acm_fopen_library_dir);
 		strcat(pname, name);
 		if (stat(pname, &statbuf) != 0) {
-			strcpy(pname, _acm_fopen_library_dir);
-			strcat(pname, name);
-			if (stat(pname, &statbuf) != 0) {
-				fprintf(stderr, errmsg, name, _acm_fopen_library_dir);
-				exit(1);
-			}
-		}
+            fprintf(stderr, errmsg, name, _acm_fopen_library_dir);
+            exit(1);
+        }		
 	}
 
 	return pname;
@@ -601,10 +589,6 @@ init (const char *runtime_directory)
     alarm_id_t id;
     char ground[256];
 
-	if (runtime_directory != NULL) {
-		strcpy (_acm_fopen_library_dir, runtime_directory);
-	}
-
     polyCount = 32768;
     poly = (VPolygon **) Vmalloc (sizeof (VPolygon *) * polyCount);
 
@@ -636,6 +620,7 @@ init (const char *runtime_directory)
     HUDColor = VAllocColor ("white");
     whiteColor = VAllocColor ("white");
     blackColor = VAllocColor ("black");
+    grayColor = VAllocColor ("gray20");
     radarColor = VAllocColor ("#0c0");
     HSIMagentaColor = VAllocColor ("magenta");
     radarBackgroundColor = VAllocColor ("#094200");
