@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #if defined(SVR4)
@@ -157,7 +158,7 @@ disEntityEnterCb(int eid, dis_entity_type * etype, int force, craft ** cptr)
 
 			c->curNWDef = 0.0;
 			c->flags = 0;
-			c->radarMode = RM_OFF;
+			c->radarMode = RM_NORMAL;
 			c->curRadarTarget = -1;
 
 			for (j = 0; j < 6; ++j) {
@@ -307,7 +308,6 @@ main(int argc, char **argv)
 	char      display[64];
 	char      *sargv[2];
 	Display   *dpy;
-	FILE      *splash_file;
 
 	strcpy( display, "" );
 	strcpy( name, "" );
@@ -425,10 +425,20 @@ main(int argc, char **argv)
 	}
 
 	printf("\
-ACM version %s,  Copyright (C) 1991-1998   Riley Rainey (rrainey@ix.netcom.com)\n\n\
-ACM comes with ABSOLUTELY NO WARRANTY.\n\
-This is free software, and you are welcome to distribute it under the\n\
-conditions described in the COPYING file.\n\n", REVISION_STRING);
+ACM version %s,  Copyright (C) 1991-1998   Riley Rainey (rrainey@ix.netcom.com)\n\
+                  Copyright (C) 2010        Sergio Lopez (slp@sinrega.org)\n\n\
+This program is free software; you can redistribute it and/or modify\n\
+it under the terms of the GNU General Public License as published by\n\
+the Free Software Foundation; either version 3 of the License, or\n\
+(at your option) any later version.\n\n\
+This program is distributed in the hope that it will be useful,\n\
+but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
+GNU General Public License for more details.\n\n\
+You should have received a copy of the GNU General Public License\n\
+along with this program; if not, write to the Free Software Foundaation,\n\
+Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA\n"
+	       , REVISION_STRING);
 
 #ifdef HAVE_DIS
 	if (disInUse)
@@ -446,12 +456,6 @@ conditions described in the COPYING file.\n\n", REVISION_STRING);
 	init(".");
 
 	dpy = XOpenDisplay(display);
-	splash_file = acm_fopen ("acmlogo-unix.xwd", "r");
-
-	sargv[0] = "acm";
-	sargv[1] = NULL;
-
-	splashScreen(dpy, splash_file, 1, sargv);
 
 	news = 2;
 
