@@ -1,11 +1,11 @@
-
 /*
  *  acm : an aerial combat simulator for X
  *  Copyright (C) 1991-1997  Riley Rainey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #include "pm.h"
@@ -330,6 +330,7 @@ doPanel(craft * c, viewer * u)
 							   topLeft.x, topLeft.y,
 							   cellW - panelWMargin,
 							   cellH - panelHMargin);
+
 				XDrawImageString(u->dpy, u->win, u->gauge_gc,
 							x, y + rfth, pptr->name, strlen(pptr->name));
 #endif
@@ -359,10 +360,13 @@ doPanel(craft * c, viewer * u)
 							   topLeft.x, topLeft.y,
 							   cellW - panelWMargin,
 							   cellH - panelHMargin);
-				/*y -= rfth; */
-				XClearArea(u->dpy, u->win, x, y,
-						   rftw * panelChars,
-						   rfth + lightMargin, False);
+
+				XSetForeground(u->dpy, u->gauge_gc, VConstantColor(u->v, grayPixel));
+
+				XDrawImageString(u->dpy, u->win, u->gauge_gc,
+							x, y + rfth, pptr->name, strlen(pptr->name));
+				XSetForeground(u->dpy, u->gauge_gc, VConstantColor(u->v, whitePixel));
+
 #endif
 			}
 		}
