@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #include "pm.h"
@@ -37,12 +38,6 @@
 #include "dis.h"
 #endif
 
-#if defined(HAVE_STDLIB_H)
-#ifndef bzero
-#define bzero(s,n)      memset ((s), 0, (n))
-#endif
-#endif							/* HAVE_STDLIB_H */
-
 extern void resizePlayerWindow(craft * c, 
 							   viewer * u, 
 							   int width, 
@@ -153,7 +148,8 @@ get_pseudo_visual(Display * display, int screen, unsigned int *depth)
  */
 
 	vTemplate.screen = screen;
-	visualList = XGetVisualInfo(display, VisualScreenMask,
+	vTemplate.depth = 8;
+	visualList = XGetVisualInfo(display, VisualScreenMask | VisualDepthMask,
 								&vTemplate, &visualsMatched);
 
 	if (visualsMatched == 0)
@@ -165,8 +161,8 @@ get_pseudo_visual(Display * display, int screen, unsigned int *depth)
  */
 
 	for (i = 0; i < visualsMatched; ++i) {
-		if (visualList[i].visual->class == PseudoColor &&
-			visualList[i].depth >= 4) {
+		if (visualList[i].visual->class == TrueColor &&
+			visualList[i].depth == 8) {
 			*depth = visualList[i].depth;
 			XFree((char *) visualList);
 			return visualList[i].visual;
@@ -223,7 +219,7 @@ newPlayer(int s, char *display, char *logname, char *switches)
 	long      win_attr_mask;
 	Visual   *theVisual;
 	XSetWindowAttributes window_attributes;
-	int       useDefaultVisual = 1;
+	int       useDefaultVisual = 0;
 	int       passive = 0;
 	Atom      atom[2];
 	int       overrides[SW_LAST+1];
@@ -748,6 +744,7 @@ newPlayer(int s, char *display, char *logname, char *switches)
 
 	whitePixel = whiteColor->cIndex;
 	blackPixel = blackColor->cIndex;
+	grayPixel = grayColor->cIndex;
 	HUDPixel = HUDColor->cIndex;
 
 /*
