@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #ifndef _pm_h
@@ -674,6 +675,8 @@ extern    "C" {
 	_var_type VColor *whiteColor;	/* white in viewport(s) */
 	_var_type int blackPixel;	/* index of black in viewport(s) */
 	_var_type VColor *blackColor;	/* black in viewport(s) */
+	_var_type int grayPixel;	/* index of black in viewport(s) */
+	_var_type VColor *grayColor;	/* black in viewport(s) */
 	_var_type VColor *groundColor;	/* ground color in viewport(s) */
 	_var_type VColor *radarColor;	/* radar color */
 	_var_type VColor *radarBackgroundColor;		/* radar CRT surface color */
@@ -922,11 +925,6 @@ extern    "C" {
 #ifndef WIN32
 	extern int doBrowseKeyEvent(craft * c, viewer * u, 
 								XEvent * ev, int player);
-
-	extern int splashScreen(Display *dpy,
-							FILE *in_file, 
-							int argc, 
-							char **argv);
 #endif
 
 	extern int split (char *s, int *argc, char *argv[]);
