@@ -4,7 +4,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program;  if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+ *  along with this program; if not, write to the Free Software Foundaation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  */
 
 #include <math.h>
@@ -577,7 +578,10 @@ doRPM(craft * c, viewer * u)
 	sprintf(so, "%3d%s", (int) (percento + 0.5),
 			(c->flags & FL_AFTERBURNER) ? "AB" : "  ");
 	if (strcmp(s, c->lastRPM) != 0 || strcmp(so, c->lastRPMO) != 0) {
-
+		redrawItem(&u->rpmState);
+	}
+	
+	if (isRedrawRequired(&u->rpmState)) {
 #ifdef WIN32
 		if (rpm_g == 0) {
 			rpm_g = LoadACMBitmap(MAKEINTRESOURCE(IDB_RPM_GAUGE),
@@ -748,9 +752,8 @@ doRPM(craft * c, viewer * u)
 	 *  Display Flap Setting
 	 */
 
-	x = u->xCenter - (u->radarWidth + 1) / 2 - flaps0_width -
-		(int) (20.0 * u->scaleFactor);
-	y = u->TEWSy + u->TEWSSize + (int) (40.0 * u->scaleFactor);
+	x = u->xCenter + (u->radarWidth + 1) / 2 + (int) (20.0 * u->scaleFactor);
+	y = u->height + (int) ((VISOR_MARGIN + 20.0) * u->scaleFactor + 0.5);
 
 	sprintf(s, "Flaps: %d ", (int) RADtoDEG(c->curFlap));
 
